==> camel-quarkus-integration-test-cxf-soap-rest-3.2.2-sources.jar: org/jboss/eap/quickstarts/wscalculator/calculator/Result.java <==

package org.jboss.eap.quickstarts.wscalculator.calculator;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for result complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="result">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="operands" type="{http://www.jboss.org/eap/quickstarts/wscalculator/Calculator}operands" minOccurs="0"/>
 *         <element name="result" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "result", propOrder = {
    "operands",
    "result"
})
public class Result {

    protected Operands operands;
    protected int result;

    /**
     * Gets the value of the operands property.
     * 
     * @return
     *     possible object is
     *     {@link Operands }
     *     
     */
    public Operands getOperands() {
        return operands;
    }

    /**
     * Sets the value of the operands property.
     * 
     * @param value
     *     allowed object is
     *     {@link Operands }
     *     
     */
    public void setOperands(Operands value) {
        this.operands = value;
    }

    /**
     * Gets the value of the result property.
     * 
     */
    public int getResult() {
        return result;
    }

    /**
     * Sets the value of the result property.
     * 
     */
    public void setResult(int value) {
        this.result = value;
    }

}

==> camel-quarkus-integration-test-cxf-soap-rest-3.2.3-sources.jar: org/jboss/eap/quickstarts/wscalculator/calculator/Result.java <==

package org.jboss.eap.quickstarts.wscalculator.calculator;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>result complex type的 Java 类。
 * 
 * <p>以下模式片段指定包含在此类中的预期内容。
 * 
 * <pre>{@code
 * <complexType name="result">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="operands" type="{http://www.jboss.org/eap/quickstarts/wscalculator/Calculator}operands" minOccurs="0"/>
 *         <element name="result" type="{http://www.w3.org/2001/XMLSchema}int"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "result", propOrder = {
    "operands",
    "result"
})
public class Result {

    protected Operands operands;
    protected int result;

    /**
     * 获取operands属性的值。
     * 
     * @return
     *     possible object is
     *     {@link Operands }
     *     
     */
    public Operands getOperands() {
        return operands;
    }

    /**
     * 设置operands属性的值。
     * 
     * @param value
     *     allowed object is
     *     {@link Operands }
     *     
     */
    public void setOperands(Operands value) {
        this.operands = value;
    }

    /**
     * 获取result属性的值。
     * 
     */
    public int getResult() {
        return result;
    }

    /**
     * 设置result属性的值。
     * 
     */
    public void setResult(int value) {
        this.result = value;
    }

}
